@@ -11,8 +11,14 @@ import ddtrace
 
 from simple_api_framework.monitors import DataDogMonitor
 
-if os.getenv("DATADOG_ENABLED"):
+if os.getenv("DD_SERVICE") and os.getenv("DD_API_KEY") and os.getenv("DD_API_KEY") and os.getenv("DD_ENV"):
     ddtrace.patch(tornado=True)
+    if os.getenv("REDIS_URL"):
+        ddtrace.patch(aioredis=True)
+    if os.getenv("MONGODB_URL"):
+        ddtrace.patch(mongoengine=True)
+    if os.getenv("DB_URL"):
+        ddtrace.patch(aiopg=True)
 
 import dotenv
 import magic
